@@ -10,6 +10,7 @@ use Encode;
 use JSON;
 use HTTP::Request;
 use LWP::UserAgent;
+use LWP::Protocol::https;
 use URI;
 
 =head1 NAME
@@ -18,11 +19,11 @@ Geo::Coder::CA - Provides a geocoding functionality using http:://geocoder.ca fo
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -84,19 +85,37 @@ sub geocode {
 
 	my $uri = URI->new("https://$self->{host}/some_location");
 	$location =~ s/\s/+/g;
-	my %query_parameters = ('locate' => $location);
-	$query_parameters{json} = 1;
+	my %query_parameters = ('locate' => $location, 'json' => 1);
 	$uri->query_form(%query_parameters);
-	my $url = $uri->as_string;
+	my $url = $uri->as_string();
 
 	my $res = $self->{ua}->get($url);
 
-	if ($res->is_error) {
-		Carp::croak("geocode.ca API returned error: " . $res->status_line());
+	if($res->is_error()) {
+		Carp::croak("geocoder.ca API returned error: " . $res->status_line());
+		return;
 	}
 
-	my $json = JSON->new->utf8;
-	return $json->decode($res->content);	# No support for list context, yet
+	my $json = JSON->new->utf8();
+	my $rc = $json->decode($res->content());
+	if($rc && $rc->{'latt'} && $rc->{'longt'}) {
+		return $rc;	# No support for list context, yet
+	}
+
+	if($location =~ /^(\w+),\+*(\w+),\+*(USA|US|United States)$/i) {
+		$query_parameters{'locate'} = "$1 County, $2, $3";
+		$uri->query_form(%query_parameters);
+		$url = $uri->as_string();
+
+		$res = $self->{ua}->get($url);
+
+		if($res->is_error()) {
+			Carp::croak("geocoder.ca API returned error: " . $res->status_line());
+			return;
+		}
+		return $json->decode($res->content());
+	}
+	return;
 
 	# my @results = @{ $data || [] };
 	# wantarray ? @results : $results[0];
@@ -112,7 +131,7 @@ environment variables:
 
 You can also set your own User-Agent object:
 
-  $geocoder->ua(LWPx::ParanoidAgent->new());
+  $geocoder->ua(LWP::UserAgent::Throttled->new());
 
 =cut
 
